==> ark-17.04.0.tar.xz: ark-17.04.0/plugins/libzipplugin/kerfuffle_libzip.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the zip archive format",
        "Description[ca@valencia]": "Implementació completa del format d'arxiu ZIP",
        "Description[ca]": "Implementació completa del format d'arxiu ZIP",
        "Description[cs]": "Plná podpora archivačního formátu zip",
        "Description[de]": "Vollständige Unterstützung für Zip-Archivformate",
        "Description[es]": "Uso total del formato de archivo comprimido zip",
        "Description[it]": "Supporto completo per il formato di archivi ZIP",
        "Description[nl]": "Volledige ondersteuning voor het zip-archiefformaat",
        "Description[pl]": "Pełna obsługa dla formatów archiwów zip",
        "Description[pt]": "Suporte total para o formato de pacotes ZIP",
        "Description[sl]": "Polna podpora za arhive vrste zip",
        "Description[sr@ijekavian]": "Пуна подршка за архивски формат ЗИП",
        "Description[sr@ijekavianlatin]": "Puna podrška za arhivski format ZIP",
        "Description[sr@latin]": "Puna podrška za arhivski format ZIP",
        "Description[sr]": "Пуна подршка за архивски формат ЗИП",
        "Description[sv]": "Fullt stöd för arkivformatet zip",
        "Description[uk]": "Повноцінна підтримка архівів у форматі zip",
        "Description[x-test]": "xxFull support for the zip archive formatxx",
        "Description[zh_TW]": "對 zip 壓縮檔格式的完整支援",
        "Id": "kerfuffle_libzip",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Libzip plugin",
        "Name[ca@valencia]": "Connector del Libzip",
        "Name[ca]": "Connector del Libzip",
        "Name[cs]": "Modul pro libzip",
        "Name[de]": "Libzip-Modul",
        "Name[es]": "Complemento Libzip",
        "Name[it]": "Estensione Libzip",
        "Name[nl]": "Libzip-plug-in",
        "Name[pl]": "Wtyczka libzip",
        "Name[pt]": "'Plugin' da Libzip",
        "Name[sl]": "Vstavek Libzip",
        "Name[sr@ijekavian]": "Прикључак за Либзип",
        "Name[sr@ijekavianlatin]": "Priključak za libzip",
        "Name[sr@latin]": "Priključak za libzip",
        "Name[sr]": "Прикључак за Либзип",
        "Name[sv]": "Libzip-insticksprogram",
        "Name[uk]": "Додаток libzip",
        "Name[x-test]": "xxLibzip pluginxx",
        "Name[zh_TW]": "Libzip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 200,
    "application/zip": {
        "Encryption": true,
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256",
            "AES192",
            "AES128"
        ],
        "SupportsTesting": true,
        "SupportsWriteComment": true
    }
}

==> ark-17.04.1.tar.xz: ark-17.04.1/plugins/libzipplugin/kerfuffle_libzip.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the zip archive format",
        "Description[ca@valencia]": "Implementació completa del format d'arxiu ZIP",
        "Description[ca]": "Implementació completa del format d'arxiu ZIP",
        "Description[cs]": "Plná podpora archivačního formátu zip",
        "Description[de]": "Vollständige Unterstützung für Zip-Archivformate",
        "Description[es]": "Uso total del formato de archivo comprimido zip",
        "Description[it]": "Supporto completo per il formato di archivi ZIP",
        "Description[nl]": "Volledige ondersteuning voor het zip-archiefformaat",
        "Description[pl]": "Pełna obsługa dla formatów archiwów zip",
        "Description[pt]": "Suporte total para o formato de pacotes ZIP",
        "Description[sk]": "Plná podpora pre archívny formát zip",
        "Description[sl]": "Polna podpora za arhive vrste zip",
        "Description[sr@ijekavian]": "Пуна подршка за архивски формат ЗИП",
        "Description[sr@ijekavianlatin]": "Puna podrška za arhivski format ZIP",
        "Description[sr@latin]": "Puna podrška za arhivski format ZIP",
        "Description[sr]": "Пуна подршка за архивски формат ЗИП",
        "Description[sv]": "Fullt stöd för arkivformatet zip",
        "Description[uk]": "Повноцінна підтримка архівів у форматі zip",
        "Description[x-test]": "xxFull support for the zip archive formatxx",
        "Description[zh_CN]": "完全支持 zip 归档格式",
        "Description[zh_TW]": "對 zip 壓縮檔格式的完整支援",
        "Id": "kerfuffle_libzip",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Libzip plugin",
        "Name[ca@valencia]": "Connector del Libzip",
        "Name[ca]": "Connector del Libzip",
        "Name[cs]": "Modul pro libzip",
        "Name[de]": "Libzip-Modul",
        "Name[es]": "Complemento Libzip",
        "Name[it]": "Estensione Libzip",
        "Name[nl]": "Libzip-plug-in",
        "Name[pl]": "Wtyczka libzip",
        "Name[pt]": "'Plugin' da Libzip",
        "Name[sk]": "Plugin Libzip",
        "Name[sl]": "Vstavek Libzip",
        "Name[sr@ijekavian]": "Прикључак за Либзип",
        "Name[sr@ijekavianlatin]": "Priključak za libzip",
        "Name[sr@latin]": "Priključak za libzip",
        "Name[sr]": "Прикључак за Либзип",
        "Name[sv]": "Libzip-insticksprogram",
        "Name[uk]": "Додаток libzip",
        "Name[x-test]": "xxLibzip pluginxx",
        "Name[zh_CN]": "Libzip 插件",
        "Name[zh_TW]": "Libzip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 200,
    "application/zip": {
        "Encryption": true,
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256",
            "AES192",
            "AES128"
        ],
        "SupportsTesting": true,
        "SupportsWriteComment": true
    }
}
